# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Iterable as typing___Iterable, Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
)
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BidModifierSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___BidModifierSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___BidModifierSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___BidModifierSimulationPointList = BidModifierSimulationPointList

class CpcBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CpcBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___CpcBidSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___CpcBidSimulationPointList = CpcBidSimulationPointList

class CpvBidSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CpvBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___CpvBidSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___CpvBidSimulationPointList = CpvBidSimulationPointList

class TargetCpaSimulationPointList(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def points(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___TargetCpaSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing___Optional[
            typing___Iterable[type___TargetCpaSimulationPoint]
        ] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["points", b"points"]
    ) -> None: ...

type___TargetCpaSimulationPointList = TargetCpaSimulationPointList

class BidModifierSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def biddable_conversions(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def parent_biddable_conversions(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def parent_biddable_conversions_value(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def parent_clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def parent_cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def parent_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def parent_top_slot_impressions(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def parent_required_budget_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        bid_modifier: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        biddable_conversions: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        biddable_conversions_value: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        clicks: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        top_slot_impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        parent_biddable_conversions: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        parent_biddable_conversions_value: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        parent_clicks: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        parent_cost_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        parent_impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        parent_top_slot_impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        parent_required_budget_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

type___BidModifierSimulationPoint = BidModifierSimulationPoint

class CpcBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def biddable_conversions(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        cpc_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        biddable_conversions: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        biddable_conversions_value: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        clicks: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        top_slot_impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

type___CpcBidSimulationPoint = CpcBidSimulationPoint

class CpvBidSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def cpv_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def views(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        cpv_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        cost_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        views: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> None: ...

type___CpvBidSimulationPoint = CpvBidSimulationPoint

class TargetCpaSimulationPoint(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def target_cpa_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def biddable_conversions(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def biddable_conversions_value(
        self,
    ) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def clicks(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def cost_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def top_slot_impressions(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        target_cpa_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        biddable_conversions: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        biddable_conversions_value: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        clicks: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        cost_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        top_slot_impressions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...

type___TargetCpaSimulationPoint = TargetCpaSimulationPoint



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class VanityPharmaTextEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    VanityPharmaTextValue = typing___NewType("VanityPharmaTextValue", builtin___int)
    type___VanityPharmaTextValue = VanityPharmaTextValue
    VanityPharmaText: _VanityPharmaText
    class _VanityPharmaText(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            VanityPharmaTextEnum.VanityPharmaTextValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(VanityPharmaTextEnum.VanityPharmaTextValue, 0)
        UNKNOWN = typing___cast(VanityPharmaTextEnum.VanityPharmaTextValue, 1)
        PRESCRIPTION_TREATMENT_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 2
        )
        PRESCRIPTION_TREATMENT_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 3
        )
        PRESCRIPTION_DEVICE_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 4
        )
        PRESCRIPTION_DEVICE_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 5
        )
        MEDICAL_DEVICE_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 6
        )
        MEDICAL_DEVICE_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 7
        )
        PREVENTATIVE_TREATMENT_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 8
        )
        PREVENTATIVE_TREATMENT_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 9
        )
        PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 10
        )
        PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 11
        )
        PRESCRIPTION_VACCINE_WEBSITE_EN = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 12
        )
        PRESCRIPTION_VACCINE_WEBSITE_ES = typing___cast(
            VanityPharmaTextEnum.VanityPharmaTextValue, 13
        )
    UNSPECIFIED = typing___cast(VanityPharmaTextEnum.VanityPharmaTextValue, 0)
    UNKNOWN = typing___cast(VanityPharmaTextEnum.VanityPharmaTextValue, 1)
    PRESCRIPTION_TREATMENT_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 2
    )
    PRESCRIPTION_TREATMENT_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 3
    )
    PRESCRIPTION_DEVICE_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 4
    )
    PRESCRIPTION_DEVICE_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 5
    )
    MEDICAL_DEVICE_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 6
    )
    MEDICAL_DEVICE_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 7
    )
    PREVENTATIVE_TREATMENT_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 8
    )
    PREVENTATIVE_TREATMENT_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 9
    )
    PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 10
    )
    PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 11
    )
    PRESCRIPTION_VACCINE_WEBSITE_EN = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 12
    )
    PRESCRIPTION_VACCINE_WEBSITE_ES = typing___cast(
        VanityPharmaTextEnum.VanityPharmaTextValue, 13
    )
    type___VanityPharmaText = VanityPharmaText
    def __init__(self,) -> None: ...

type___VanityPharmaTextEnum = VanityPharmaTextEnum



from typing import Any

class ReachPlanServiceStub:
    ListPlannableLocations: Any = ...
    ListPlannableProducts: Any = ...
    GenerateProductMixIdeas: Any = ...
    GenerateReachForecast: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ReachPlanServiceServicer:
    def ListPlannableLocations(self, request: Any, context: Any) -> None: ...
    def ListPlannableProducts(self, request: Any, context: Any) -> None: ...
    def GenerateProductMixIdeas(self, request: Any, context: Any) -> None: ...
    def GenerateReachForecast(self, request: Any, context: Any) -> None: ...

def add_ReachPlanServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ResourceChangeOperationEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ResourceChangeOperationValue = typing___NewType(
        "ResourceChangeOperationValue", builtin___int
    )
    type___ResourceChangeOperationValue = ResourceChangeOperationValue
    ResourceChangeOperation: _ResourceChangeOperation
    class _ResourceChangeOperation(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ResourceChangeOperationEnum.ResourceChangeOperationValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ResourceChangeOperationEnum.ResourceChangeOperationValue, 0
        )
        UNKNOWN = typing___cast(
            ResourceChangeOperationEnum.ResourceChangeOperationValue, 1
        )
        CREATE = typing___cast(
            ResourceChangeOperationEnum.ResourceChangeOperationValue, 2
        )
        UPDATE = typing___cast(
            ResourceChangeOperationEnum.ResourceChangeOperationValue, 3
        )
        REMOVE = typing___cast(
            ResourceChangeOperationEnum.ResourceChangeOperationValue, 4
        )
    UNSPECIFIED = typing___cast(
        ResourceChangeOperationEnum.ResourceChangeOperationValue, 0
    )
    UNKNOWN = typing___cast(ResourceChangeOperationEnum.ResourceChangeOperationValue, 1)
    CREATE = typing___cast(ResourceChangeOperationEnum.ResourceChangeOperationValue, 2)
    UPDATE = typing___cast(ResourceChangeOperationEnum.ResourceChangeOperationValue, 3)
    REMOVE = typing___cast(ResourceChangeOperationEnum.ResourceChangeOperationValue, 4)
    type___ResourceChangeOperation = ResourceChangeOperation
    def __init__(self,) -> None: ...

type___ResourceChangeOperationEnum = ResourceChangeOperationEnum



from typing import Any

class KeywordPlanCampaignServiceStub:
    GetKeywordPlanCampaign: Any = ...
    MutateKeywordPlanCampaigns: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanCampaignServiceServicer:
    def GetKeywordPlanCampaign(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlanCampaigns(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanCampaignServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemTargetErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemTargetErrorValue = typing___NewType(
        "FeedItemTargetErrorValue", builtin___int
    )
    type___FeedItemTargetErrorValue = FeedItemTargetErrorValue
    FeedItemTargetError: _FeedItemTargetError
    class _FeedItemTargetError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 0)
        UNKNOWN = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 1)
        MUST_SET_TARGET_ONEOF_ON_CREATE = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 2
        )
        FEED_ITEM_TARGET_ALREADY_EXISTS = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 3
        )
        FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 4
        )
        TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 5
        )
        TOO_MANY_SCHEDULES_PER_DAY = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 6
        )
        CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 7
        )
        DUPLICATE_AD_SCHEDULE = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 8
        )
        DUPLICATE_KEYWORD = typing___cast(
            FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 9
        )
    UNSPECIFIED = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 0)
    UNKNOWN = typing___cast(FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 1)
    MUST_SET_TARGET_ONEOF_ON_CREATE = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 2
    )
    FEED_ITEM_TARGET_ALREADY_EXISTS = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 3
    )
    FEED_ITEM_SCHEDULES_CANNOT_OVERLAP = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 4
    )
    TARGET_LIMIT_EXCEEDED_FOR_GIVEN_TYPE = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 5
    )
    TOO_MANY_SCHEDULES_PER_DAY = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 6
    )
    CANNOT_HAVE_ENABLED_CAMPAIGN_AND_ENABLED_AD_GROUP_TARGETS = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 7
    )
    DUPLICATE_AD_SCHEDULE = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 8
    )
    DUPLICATE_KEYWORD = typing___cast(
        FeedItemTargetErrorEnum.FeedItemTargetErrorValue, 9
    )
    type___FeedItemTargetError = FeedItemTargetError
    def __init__(self,) -> None: ...

type___FeedItemTargetErrorEnum = FeedItemTargetErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Iterable as typing___Iterable, Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UrlCollection(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def url_collection_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def final_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def final_mobile_urls(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def tracking_url_template(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        url_collection_id: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        final_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        final_mobile_urls: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        tracking_url_template: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_urls",
            b"final_urls",
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> None: ...

type___UrlCollection = UrlCollection



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.account_budget_proposal_status_pb2 import (
    AccountBudgetProposalStatusEnum as google___ads___googleads___v4___enums___account_budget_proposal_status_pb2___AccountBudgetProposalStatusEnum,
)
from google.ads.google_ads.v4.proto.enums.account_budget_proposal_type_pb2 import (
    AccountBudgetProposalTypeEnum as google___ads___googleads___v4___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.spending_limit_type_pb2 import (
    SpendingLimitTypeEnum as google___ads___googleads___v4___enums___spending_limit_type_pb2___SpendingLimitTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.time_type_pb2 import (
    TimeTypeEnum as google___ads___googleads___v4___enums___time_type_pb2___TimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountBudgetProposal(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    proposal_type: google___ads___googleads___v4___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum.AccountBudgetProposalTypeValue = ...
    status: google___ads___googleads___v4___enums___account_budget_proposal_status_pb2___AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue = ...
    proposed_start_time_type: google___ads___googleads___v4___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
    proposed_end_time_type: google___ads___googleads___v4___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
    approved_end_time_type: google___ads___googleads___v4___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue = ...
    proposed_spending_limit_type: google___ads___googleads___v4___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
    approved_spending_limit_type: google___ads___googleads___v4___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def billing_setup(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def account_budget(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def proposed_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def approved_start_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def proposed_purchase_order_number(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def proposed_notes(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def creation_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def approval_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def proposed_start_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def proposed_end_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def approved_end_date_time(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def proposed_spending_limit_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def approved_spending_limit_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        billing_setup: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        account_budget: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        proposal_type: typing___Optional[
            google___ads___googleads___v4___enums___account_budget_proposal_type_pb2___AccountBudgetProposalTypeEnum.AccountBudgetProposalTypeValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v4___enums___account_budget_proposal_status_pb2___AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue
        ] = None,
        proposed_name: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        approved_start_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        proposed_purchase_order_number: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        proposed_notes: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        creation_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        approval_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        proposed_start_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        proposed_start_time_type: typing___Optional[
            google___ads___googleads___v4___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
        ] = None,
        proposed_end_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        proposed_end_time_type: typing___Optional[
            google___ads___googleads___v4___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
        ] = None,
        approved_end_date_time: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        approved_end_time_type: typing___Optional[
            google___ads___googleads___v4___enums___time_type_pb2___TimeTypeEnum.TimeTypeValue
        ] = None,
        proposed_spending_limit_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        proposed_spending_limit_type: typing___Optional[
            google___ads___googleads___v4___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
        ] = None,
        approved_spending_limit_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        approved_spending_limit_type: typing___Optional[
            google___ads___googleads___v4___enums___spending_limit_type_pb2___SpendingLimitTypeEnum.SpendingLimitTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "account_budget",
            b"account_budget",
            "approval_date_time",
            b"approval_date_time",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "creation_date_time",
            b"creation_date_time",
            "id",
            b"id",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_name",
            b"proposed_name",
            "proposed_notes",
            b"proposed_notes",
            "proposed_purchase_order_number",
            b"proposed_purchase_order_number",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "proposed_start_time",
            b"proposed_start_time",
            "proposed_start_time_type",
            b"proposed_start_time_type",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "account_budget",
            b"account_budget",
            "approval_date_time",
            b"approval_date_time",
            "approved_end_date_time",
            b"approved_end_date_time",
            "approved_end_time",
            b"approved_end_time",
            "approved_end_time_type",
            b"approved_end_time_type",
            "approved_spending_limit",
            b"approved_spending_limit",
            "approved_spending_limit_micros",
            b"approved_spending_limit_micros",
            "approved_spending_limit_type",
            b"approved_spending_limit_type",
            "approved_start_date_time",
            b"approved_start_date_time",
            "billing_setup",
            b"billing_setup",
            "creation_date_time",
            b"creation_date_time",
            "id",
            b"id",
            "proposal_type",
            b"proposal_type",
            "proposed_end_date_time",
            b"proposed_end_date_time",
            "proposed_end_time",
            b"proposed_end_time",
            "proposed_end_time_type",
            b"proposed_end_time_type",
            "proposed_name",
            b"proposed_name",
            "proposed_notes",
            b"proposed_notes",
            "proposed_purchase_order_number",
            b"proposed_purchase_order_number",
            "proposed_spending_limit",
            b"proposed_spending_limit",
            "proposed_spending_limit_micros",
            b"proposed_spending_limit_micros",
            "proposed_spending_limit_type",
            b"proposed_spending_limit_type",
            "proposed_start_date_time",
            b"proposed_start_date_time",
            "proposed_start_time",
            b"proposed_start_time",
            "proposed_start_time_type",
            b"proposed_start_time_type",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "approved_end_time", b"approved_end_time"
        ],
    ) -> typing_extensions___Literal[
        "approved_end_date_time", "approved_end_time_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "approved_spending_limit", b"approved_spending_limit"
        ],
    ) -> typing_extensions___Literal[
        "approved_spending_limit_micros", "approved_spending_limit_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "proposed_end_time", b"proposed_end_time"
        ],
    ) -> typing_extensions___Literal[
        "proposed_end_date_time", "proposed_end_time_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "proposed_spending_limit", b"proposed_spending_limit"
        ],
    ) -> typing_extensions___Literal[
        "proposed_spending_limit_micros", "proposed_spending_limit_type"
    ]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "proposed_start_time", b"proposed_start_time"
        ],
    ) -> typing_extensions___Literal[
        "proposed_start_date_time", "proposed_start_time_type"
    ]: ...

type___AccountBudgetProposal = AccountBudgetProposal



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedItemErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedItemErrorValue = typing___NewType("FeedItemErrorValue", builtin___int)
    type___FeedItemErrorValue = FeedItemErrorValue
    FeedItemError: _FeedItemError
    class _FeedItemError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedItemErrorEnum.FeedItemErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 0)
        UNKNOWN = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 1)
        CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 2
        )
        CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 3
        )
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 4
        )
        KEY_ATTRIBUTES_NOT_FOUND = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 5
        )
        INVALID_URL = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 6)
        MISSING_KEY_ATTRIBUTES = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 7)
        KEY_ATTRIBUTES_NOT_UNIQUE = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 8
        )
        CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 9
        )
        SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = typing___cast(
            FeedItemErrorEnum.FeedItemErrorValue, 10
        )
    UNSPECIFIED = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 0)
    UNKNOWN = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 1)
    CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 2
    )
    CANNOT_OPERATE_ON_REMOVED_FEED_ITEM = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 3
    )
    DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 4
    )
    KEY_ATTRIBUTES_NOT_FOUND = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 5)
    INVALID_URL = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 6)
    MISSING_KEY_ATTRIBUTES = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 7)
    KEY_ATTRIBUTES_NOT_UNIQUE = typing___cast(FeedItemErrorEnum.FeedItemErrorValue, 8)
    CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 9
    )
    SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE = typing___cast(
        FeedItemErrorEnum.FeedItemErrorValue, 10
    )
    type___FeedItemError = FeedItemError
    def __init__(self,) -> None: ...

type___FeedItemErrorEnum = FeedItemErrorEnum



from typing import Any

class FeedServiceStub:
    GetFeed: Any = ...
    MutateFeeds: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedServiceServicer:
    def GetFeed(self, request: Any, context: Any) -> None: ...
    def MutateFeeds(self, request: Any, context: Any) -> None: ...

def add_FeedServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



from typing import Any

class DomainCategoryServiceStub:
    GetDomainCategory: Any = ...
    def __init__(self, channel: Any) -> None: ...

class DomainCategoryServiceServicer:
    def GetDomainCategory(self, request: Any, context: Any) -> None: ...

def add_DomainCategoryServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LabelErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LabelErrorValue = typing___NewType("LabelErrorValue", builtin___int)
    type___LabelErrorValue = LabelErrorValue
    LabelError: _LabelError
    class _LabelError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LabelErrorEnum.LabelErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(LabelErrorEnum.LabelErrorValue, 0)
        UNKNOWN = typing___cast(LabelErrorEnum.LabelErrorValue, 1)
        CANNOT_APPLY_INACTIVE_LABEL = typing___cast(LabelErrorEnum.LabelErrorValue, 2)
        CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION = typing___cast(
            LabelErrorEnum.LabelErrorValue, 3
        )
        CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION = typing___cast(
            LabelErrorEnum.LabelErrorValue, 4
        )
        EXCEEDED_LABEL_LIMIT_PER_TYPE = typing___cast(LabelErrorEnum.LabelErrorValue, 5)
        INVALID_RESOURCE_FOR_MANAGER_LABEL = typing___cast(
            LabelErrorEnum.LabelErrorValue, 6
        )
        DUPLICATE_NAME = typing___cast(LabelErrorEnum.LabelErrorValue, 7)
        INVALID_LABEL_NAME = typing___cast(LabelErrorEnum.LabelErrorValue, 8)
        CANNOT_ATTACH_LABEL_TO_DRAFT = typing___cast(LabelErrorEnum.LabelErrorValue, 9)
        CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER = typing___cast(
            LabelErrorEnum.LabelErrorValue, 10
        )
    UNSPECIFIED = typing___cast(LabelErrorEnum.LabelErrorValue, 0)
    UNKNOWN = typing___cast(LabelErrorEnum.LabelErrorValue, 1)
    CANNOT_APPLY_INACTIVE_LABEL = typing___cast(LabelErrorEnum.LabelErrorValue, 2)
    CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION = typing___cast(
        LabelErrorEnum.LabelErrorValue, 3
    )
    CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION = typing___cast(
        LabelErrorEnum.LabelErrorValue, 4
    )
    EXCEEDED_LABEL_LIMIT_PER_TYPE = typing___cast(LabelErrorEnum.LabelErrorValue, 5)
    INVALID_RESOURCE_FOR_MANAGER_LABEL = typing___cast(
        LabelErrorEnum.LabelErrorValue, 6
    )
    DUPLICATE_NAME = typing___cast(LabelErrorEnum.LabelErrorValue, 7)
    INVALID_LABEL_NAME = typing___cast(LabelErrorEnum.LabelErrorValue, 8)
    CANNOT_ATTACH_LABEL_TO_DRAFT = typing___cast(LabelErrorEnum.LabelErrorValue, 9)
    CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER = typing___cast(
        LabelErrorEnum.LabelErrorValue, 10
    )
    type___LabelError = LabelError
    def __init__(self,) -> None: ...

type___LabelErrorEnum = LabelErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedAttributeTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedAttributeTypeValue = typing___NewType("FeedAttributeTypeValue", builtin___int)
    type___FeedAttributeTypeValue = FeedAttributeTypeValue
    FeedAttributeType: _FeedAttributeType
    class _FeedAttributeType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedAttributeTypeEnum.FeedAttributeTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 0)
        UNKNOWN = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 1)
        INT64 = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 2)
        DOUBLE = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 3)
        STRING = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 4)
        BOOLEAN = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 5)
        URL = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 6)
        DATE_TIME = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 7)
        INT64_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 8)
        DOUBLE_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 9)
        STRING_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 10)
        BOOLEAN_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 11)
        URL_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 12)
        DATE_TIME_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 13)
        PRICE = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 14)
    UNSPECIFIED = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 0)
    UNKNOWN = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 1)
    INT64 = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 2)
    DOUBLE = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 3)
    STRING = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 4)
    BOOLEAN = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 5)
    URL = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 6)
    DATE_TIME = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 7)
    INT64_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 8)
    DOUBLE_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 9)
    STRING_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 10)
    BOOLEAN_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 11)
    URL_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 12)
    DATE_TIME_LIST = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 13)
    PRICE = typing___cast(FeedAttributeTypeEnum.FeedAttributeTypeValue, 14)
    type___FeedAttributeType = FeedAttributeType
    def __init__(self,) -> None: ...

type___FeedAttributeTypeEnum = FeedAttributeTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class MutateErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    MutateErrorValue = typing___NewType("MutateErrorValue", builtin___int)
    type___MutateErrorValue = MutateErrorValue
    MutateError: _MutateError
    class _MutateError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            MutateErrorEnum.MutateErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(MutateErrorEnum.MutateErrorValue, 0)
        UNKNOWN = typing___cast(MutateErrorEnum.MutateErrorValue, 1)
        RESOURCE_NOT_FOUND = typing___cast(MutateErrorEnum.MutateErrorValue, 3)
        ID_EXISTS_IN_MULTIPLE_MUTATES = typing___cast(
            MutateErrorEnum.MutateErrorValue, 7
        )
        INCONSISTENT_FIELD_VALUES = typing___cast(MutateErrorEnum.MutateErrorValue, 8)
        MUTATE_NOT_ALLOWED = typing___cast(MutateErrorEnum.MutateErrorValue, 9)
        RESOURCE_NOT_IN_GOOGLE_ADS = typing___cast(MutateErrorEnum.MutateErrorValue, 10)
        RESOURCE_ALREADY_EXISTS = typing___cast(MutateErrorEnum.MutateErrorValue, 11)
        RESOURCE_DOES_NOT_SUPPORT_VALIDATE_ONLY = typing___cast(
            MutateErrorEnum.MutateErrorValue, 12
        )
        RESOURCE_READ_ONLY = typing___cast(MutateErrorEnum.MutateErrorValue, 13)
    UNSPECIFIED = typing___cast(MutateErrorEnum.MutateErrorValue, 0)
    UNKNOWN = typing___cast(MutateErrorEnum.MutateErrorValue, 1)
    RESOURCE_NOT_FOUND = typing___cast(MutateErrorEnum.MutateErrorValue, 3)
    ID_EXISTS_IN_MULTIPLE_MUTATES = typing___cast(MutateErrorEnum.MutateErrorValue, 7)
    INCONSISTENT_FIELD_VALUES = typing___cast(MutateErrorEnum.MutateErrorValue, 8)
    MUTATE_NOT_ALLOWED = typing___cast(MutateErrorEnum.MutateErrorValue, 9)
    RESOURCE_NOT_IN_GOOGLE_ADS = typing___cast(MutateErrorEnum.MutateErrorValue, 10)
    RESOURCE_ALREADY_EXISTS = typing___cast(MutateErrorEnum.MutateErrorValue, 11)
    RESOURCE_DOES_NOT_SUPPORT_VALIDATE_ONLY = typing___cast(
        MutateErrorEnum.MutateErrorValue, 12
    )
    RESOURCE_READ_ONLY = typing___cast(MutateErrorEnum.MutateErrorValue, 13)
    type___MutateError = MutateError
    def __init__(self,) -> None: ...

type___MutateErrorEnum = MutateErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ListingGroupTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ListingGroupTypeValue = typing___NewType("ListingGroupTypeValue", builtin___int)
    type___ListingGroupTypeValue = ListingGroupTypeValue
    ListingGroupType: _ListingGroupType
    class _ListingGroupType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ListingGroupTypeEnum.ListingGroupTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 0)
        UNKNOWN = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 1)
        SUBDIVISION = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 2)
        UNIT = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 3)
    UNSPECIFIED = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 0)
    UNKNOWN = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 1)
    SUBDIVISION = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 2)
    UNIT = typing___cast(ListingGroupTypeEnum.ListingGroupTypeValue, 3)
    type___ListingGroupType = ListingGroupType
    def __init__(self,) -> None: ...

type___ListingGroupTypeEnum = ListingGroupTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ReachPlanAdLengthEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ReachPlanAdLengthValue = typing___NewType("ReachPlanAdLengthValue", builtin___int)
    type___ReachPlanAdLengthValue = ReachPlanAdLengthValue
    ReachPlanAdLength: _ReachPlanAdLength
    class _ReachPlanAdLength(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ReachPlanAdLengthEnum.ReachPlanAdLengthValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 0)
        UNKNOWN = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 1)
        SIX_SECONDS = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 2)
        FIFTEEN_OR_TWENTY_SECONDS = typing___cast(
            ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 3
        )
        TWENTY_SECONDS_OR_MORE = typing___cast(
            ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 4
        )
    UNSPECIFIED = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 0)
    UNKNOWN = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 1)
    SIX_SECONDS = typing___cast(ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 2)
    FIFTEEN_OR_TWENTY_SECONDS = typing___cast(
        ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 3
    )
    TWENTY_SECONDS_OR_MORE = typing___cast(
        ReachPlanAdLengthEnum.ReachPlanAdLengthValue, 4
    )
    type___ReachPlanAdLength = ReachPlanAdLength
    def __init__(self,) -> None: ...

type___ReachPlanAdLengthEnum = ReachPlanAdLengthEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.common.asset_types_pb2 import (
    BookOnGoogleAsset as google___ads___googleads___v6___common___asset_types_pb2___BookOnGoogleAsset,
    ImageAsset as google___ads___googleads___v6___common___asset_types_pb2___ImageAsset,
    LeadFormAsset as google___ads___googleads___v6___common___asset_types_pb2___LeadFormAsset,
    MediaBundleAsset as google___ads___googleads___v6___common___asset_types_pb2___MediaBundleAsset,
    TextAsset as google___ads___googleads___v6___common___asset_types_pb2___TextAsset,
    YoutubeVideoAsset as google___ads___googleads___v6___common___asset_types_pb2___YoutubeVideoAsset,
)
from google.ads.google_ads.v6.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v6___common___policy_pb2___PolicyTopicEntry,
)
from google.ads.google_ads.v6.proto.enums.asset_type_pb2 import (
    AssetTypeEnum as google___ads___googleads___v6___enums___asset_type_pb2___AssetTypeEnum,
)
from google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2 import (
    PolicyApprovalStatusEnum as google___ads___googleads___v6___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum,
)
from google.ads.google_ads.v6.proto.enums.policy_review_status_pb2 import (
    PolicyReviewStatusEnum as google___ads___googleads___v6___enums___policy_review_status_pb2___PolicyReviewStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Asset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    name: typing___Text = ...
    type: google___ads___googleads___v6___enums___asset_type_pb2___AssetTypeEnum.AssetTypeValue = ...
    final_urls: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    @property
    def policy_summary(self) -> type___AssetPolicySummary: ...
    @property
    def youtube_video_asset(
        self,
    ) -> google___ads___googleads___v6___common___asset_types_pb2___YoutubeVideoAsset: ...
    @property
    def media_bundle_asset(
        self,
    ) -> google___ads___googleads___v6___common___asset_types_pb2___MediaBundleAsset: ...
    @property
    def image_asset(
        self,
    ) -> google___ads___googleads___v6___common___asset_types_pb2___ImageAsset: ...
    @property
    def text_asset(
        self,
    ) -> google___ads___googleads___v6___common___asset_types_pb2___TextAsset: ...
    @property
    def lead_form_asset(
        self,
    ) -> google___ads___googleads___v6___common___asset_types_pb2___LeadFormAsset: ...
    @property
    def book_on_google_asset(
        self,
    ) -> google___ads___googleads___v6___common___asset_types_pb2___BookOnGoogleAsset: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        name: typing___Optional[typing___Text] = None,
        type: typing___Optional[
            google___ads___googleads___v6___enums___asset_type_pb2___AssetTypeEnum.AssetTypeValue
        ] = None,
        final_urls: typing___Optional[typing___Iterable[typing___Text]] = None,
        policy_summary: typing___Optional[type___AssetPolicySummary] = None,
        youtube_video_asset: typing___Optional[
            google___ads___googleads___v6___common___asset_types_pb2___YoutubeVideoAsset
        ] = None,
        media_bundle_asset: typing___Optional[
            google___ads___googleads___v6___common___asset_types_pb2___MediaBundleAsset
        ] = None,
        image_asset: typing___Optional[
            google___ads___googleads___v6___common___asset_types_pb2___ImageAsset
        ] = None,
        text_asset: typing___Optional[
            google___ads___googleads___v6___common___asset_types_pb2___TextAsset
        ] = None,
        lead_form_asset: typing___Optional[
            google___ads___googleads___v6___common___asset_types_pb2___LeadFormAsset
        ] = None,
        book_on_google_asset: typing___Optional[
            google___ads___googleads___v6___common___asset_types_pb2___BookOnGoogleAsset
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "asset_data",
            b"asset_data",
            "book_on_google_asset",
            b"book_on_google_asset",
            "id",
            b"id",
            "image_asset",
            b"image_asset",
            "lead_form_asset",
            b"lead_form_asset",
            "media_bundle_asset",
            b"media_bundle_asset",
            "name",
            b"name",
            "policy_summary",
            b"policy_summary",
            "text_asset",
            b"text_asset",
            "youtube_video_asset",
            b"youtube_video_asset",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_id",
            b"_id",
            "_name",
            b"_name",
            "asset_data",
            b"asset_data",
            "book_on_google_asset",
            b"book_on_google_asset",
            "final_urls",
            b"final_urls",
            "id",
            b"id",
            "image_asset",
            b"image_asset",
            "lead_form_asset",
            b"lead_form_asset",
            "media_bundle_asset",
            b"media_bundle_asset",
            "name",
            b"name",
            "policy_summary",
            b"policy_summary",
            "resource_name",
            b"resource_name",
            "text_asset",
            b"text_asset",
            "type",
            b"type",
            "youtube_video_asset",
            b"youtube_video_asset",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["asset_data", b"asset_data"]
    ) -> typing_extensions___Literal[
        "youtube_video_asset",
        "media_bundle_asset",
        "image_asset",
        "text_asset",
        "lead_form_asset",
        "book_on_google_asset",
    ]: ...

type___Asset = Asset

class AssetPolicySummary(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    review_status: google___ads___googleads___v6___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue = ...
    approval_status: google___ads___googleads___v6___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue = ...
    @property
    def policy_topic_entries(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___common___policy_pb2___PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___common___policy_pb2___PolicyTopicEntry
            ]
        ] = None,
        review_status: typing___Optional[
            google___ads___googleads___v6___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue
        ] = None,
        approval_status: typing___Optional[
            google___ads___googleads___v6___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "approval_status",
            b"approval_status",
            "policy_topic_entries",
            b"policy_topic_entries",
            "review_status",
            b"review_status",
        ],
    ) -> None: ...

type___AssetPolicySummary = AssetPolicySummary



from typing import Any, Optional

class MerchantCenterLinkServiceStub:
    ListMerchantCenterLinks: Any = ...
    GetMerchantCenterLink: Any = ...
    MutateMerchantCenterLink: Any = ...
    def __init__(self, channel: Any) -> None: ...

class MerchantCenterLinkServiceServicer:
    def ListMerchantCenterLinks(self, request: Any, context: Any) -> None: ...
    def GetMerchantCenterLink(self, request: Any, context: Any) -> None: ...
    def MutateMerchantCenterLink(self, request: Any, context: Any) -> None: ...

def add_MerchantCenterLinkServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...

class MerchantCenterLinkService:
    @staticmethod
    def ListMerchantCenterLinks(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def GetMerchantCenterLink(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateMerchantCenterLink(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ClickLocation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    city: typing___Text = ...
    country: typing___Text = ...
    metro: typing___Text = ...
    most_specific: typing___Text = ...
    region: typing___Text = ...
    def __init__(
        self,
        *,
        city: typing___Optional[typing___Text] = None,
        country: typing___Optional[typing___Text] = None,
        metro: typing___Optional[typing___Text] = None,
        most_specific: typing___Optional[typing___Text] = None,
        region: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_city",
            b"_city",
            "_country",
            b"_country",
            "_metro",
            b"_metro",
            "_most_specific",
            b"_most_specific",
            "_region",
            b"_region",
            "city",
            b"city",
            "country",
            b"country",
            "metro",
            b"metro",
            "most_specific",
            b"most_specific",
            "region",
            b"region",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_city",
            b"_city",
            "_country",
            b"_country",
            "_metro",
            b"_metro",
            "_most_specific",
            b"_most_specific",
            "_region",
            b"_region",
            "city",
            b"city",
            "country",
            b"country",
            "metro",
            b"metro",
            "most_specific",
            b"most_specific",
            "region",
            b"region",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_city", b"_city"]
    ) -> typing_extensions___Literal["city"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_country", b"_country"]
    ) -> typing_extensions___Literal["country"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_metro", b"_metro"]
    ) -> typing_extensions___Literal["metro"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_most_specific", b"_most_specific"],
    ) -> typing_extensions___Literal["most_specific"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_region", b"_region"]
    ) -> typing_extensions___Literal["region"]: ...

type___ClickLocation = ClickLocation



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DayOfWeekEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    DayOfWeekValue = typing___NewType("DayOfWeekValue", builtin___int)
    type___DayOfWeekValue = DayOfWeekValue
    DayOfWeek: _DayOfWeek
    class _DayOfWeek(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            DayOfWeekEnum.DayOfWeekValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(DayOfWeekEnum.DayOfWeekValue, 0)
        UNKNOWN = typing___cast(DayOfWeekEnum.DayOfWeekValue, 1)
        MONDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 2)
        TUESDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 3)
        WEDNESDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 4)
        THURSDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 5)
        FRIDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 6)
        SATURDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 7)
        SUNDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 8)
    UNSPECIFIED = typing___cast(DayOfWeekEnum.DayOfWeekValue, 0)
    UNKNOWN = typing___cast(DayOfWeekEnum.DayOfWeekValue, 1)
    MONDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 2)
    TUESDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 3)
    WEDNESDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 4)
    THURSDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 5)
    FRIDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 6)
    SATURDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 7)
    SUNDAY = typing___cast(DayOfWeekEnum.DayOfWeekValue, 8)
    type___DayOfWeek = DayOfWeek
    def __init__(self,) -> None: ...

type___DayOfWeekEnum = DayOfWeekEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum(
    google___protobuf___message___Message
):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue = typing___NewType(
        "PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue", builtin___int
    )
    type___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue = (
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue
    )
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorType: _PolicyTopicEvidenceDestinationNotWorkingDnsErrorType
    class _PolicyTopicEvidenceDestinationNotWorkingDnsErrorType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
            0,
        )
        UNKNOWN = typing___cast(
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
            1,
        )
        HOSTNAME_NOT_FOUND = typing___cast(
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
            2,
        )
        GOOGLE_CRAWLER_DNS_ISSUE = typing___cast(
            PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
            3,
        )
    UNSPECIFIED = typing___cast(
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
        0,
    )
    UNKNOWN = typing___cast(
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
        1,
    )
    HOSTNAME_NOT_FOUND = typing___cast(
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
        2,
    )
    GOOGLE_CRAWLER_DNS_ISSUE = typing___cast(
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeValue,
        3,
    )
    type___PolicyTopicEvidenceDestinationNotWorkingDnsErrorType = (
        PolicyTopicEvidenceDestinationNotWorkingDnsErrorType
    )
    def __init__(self,) -> None: ...

type___PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum = (
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum
)



from typing import Callable, Optional, Tuple, TypeVar

import grpc  # type: ignore
from grpc import UnaryUnaryClientInterceptor

from .interceptor import Interceptor

_Request = TypeVar("_Request")
_Response = TypeVar("_Response")

class MetadataInterceptor(
    Interceptor, grpc.UnaryUnaryClientInterceptor, grpc.UnaryStreamClientInterceptor
):
    developer_token_meta: Tuple[str, str] = ...
    login_customer_id_meta: Optional[Tuple[str, str]] = ...
    def __init__(self, developer_token: str, login_customer_id: str) -> None: ...
    def intercept_unary_unary(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...
    def intercept_unary_stream(
        self,
        continuation: Callable[[grpc.ClientCallDetails, _Request], _Response],
        client_call_details: grpc.ClientCallDetails,
        request: _Request,
    ) -> _Response: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignDraftStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CampaignDraftStatusValue = typing___NewType(
        "CampaignDraftStatusValue", builtin___int
    )
    type___CampaignDraftStatusValue = CampaignDraftStatusValue
    CampaignDraftStatus: _CampaignDraftStatus
    class _CampaignDraftStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CampaignDraftStatusEnum.CampaignDraftStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 0)
        UNKNOWN = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 1)
        PROPOSED = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 2)
        REMOVED = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 3)
        PROMOTING = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 5)
        PROMOTED = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 4)
        PROMOTE_FAILED = typing___cast(
            CampaignDraftStatusEnum.CampaignDraftStatusValue, 6
        )
    UNSPECIFIED = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 0)
    UNKNOWN = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 1)
    PROPOSED = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 2)
    REMOVED = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 3)
    PROMOTING = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 5)
    PROMOTED = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 4)
    PROMOTE_FAILED = typing___cast(CampaignDraftStatusEnum.CampaignDraftStatusValue, 6)
    type___CampaignDraftStatus = CampaignDraftStatus
    def __init__(self,) -> None: ...

type___CampaignDraftStatusEnum = CampaignDraftStatusEnum



from typing import Any

class TopicConstantServiceStub:
    GetTopicConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class TopicConstantServiceServicer:
    def GetTopicConstant(self, request: Any, context: Any) -> None: ...

def add_TopicConstantServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CriterionErrorValue = typing___NewType("CriterionErrorValue", builtin___int)
    type___CriterionErrorValue = CriterionErrorValue
    CriterionError: _CriterionError
    class _CriterionError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CriterionErrorEnum.CriterionErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 0)
        UNKNOWN = typing___cast(CriterionErrorEnum.CriterionErrorValue, 1)
        CONCRETE_TYPE_REQUIRED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 2
        )
        INVALID_EXCLUDED_CATEGORY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 3
        )
        INVALID_KEYWORD_TEXT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 4)
        KEYWORD_TEXT_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionErrorValue, 5)
        KEYWORD_HAS_TOO_MANY_WORDS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 6
        )
        KEYWORD_HAS_INVALID_CHARS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 7
        )
        INVALID_PLACEMENT_URL = typing___cast(CriterionErrorEnum.CriterionErrorValue, 8)
        INVALID_USER_LIST = typing___cast(CriterionErrorEnum.CriterionErrorValue, 9)
        INVALID_USER_INTEREST = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 10
        )
        INVALID_FORMAT_FOR_PLACEMENT_URL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 11
        )
        PLACEMENT_URL_IS_TOO_LONG = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 12
        )
        PLACEMENT_URL_HAS_ILLEGAL_CHAR = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 13
        )
        PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 14
        )
        PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 15
        )
        INVALID_TOPIC_PATH = typing___cast(CriterionErrorEnum.CriterionErrorValue, 16)
        INVALID_YOUTUBE_CHANNEL_ID = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 17
        )
        INVALID_YOUTUBE_VIDEO_ID = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 18
        )
        YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 19
        )
        YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 20
        )
        YOUTUBE_URL_UNSUPPORTED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 21
        )
        CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 22
        )
        CANNOT_ADD_CRITERIA_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 23
        )
        CANNOT_EXCLUDE_SIMILAR_USER_LIST = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 26
        )
        CANNOT_ADD_CLOSED_USER_LIST = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 27
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 28
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 29
        )
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 30
        )
        CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 31
        )
        CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 32
        )
        CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 33
        )
        INVALID_CUSTOM_AFFINITY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 96
        )
        INVALID_CUSTOM_INTENT = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 97
        )
        INVALID_IP_ADDRESS = typing___cast(CriterionErrorEnum.CriterionErrorValue, 34)
        INVALID_IP_FORMAT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 35)
        INVALID_MOBILE_APP = typing___cast(CriterionErrorEnum.CriterionErrorValue, 36)
        INVALID_MOBILE_APP_CATEGORY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 37
        )
        INVALID_CRITERION_ID = typing___cast(CriterionErrorEnum.CriterionErrorValue, 38)
        CANNOT_TARGET_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 39
        )
        CANNOT_TARGET_OBSOLETE_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 40
        )
        CRITERION_ID_AND_TYPE_MISMATCH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 41
        )
        INVALID_PROXIMITY_RADIUS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 42
        )
        INVALID_PROXIMITY_RADIUS_UNITS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 43
        )
        INVALID_STREETADDRESS_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 44
        )
        INVALID_CITYNAME_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 45
        )
        INVALID_REGIONCODE_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 46
        )
        INVALID_REGIONNAME_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 47
        )
        INVALID_POSTALCODE_LENGTH = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 48
        )
        INVALID_COUNTRY_CODE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 49)
        INVALID_LATITUDE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 50)
        INVALID_LONGITUDE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 51)
        PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 52
        )
        INVALID_PROXIMITY_ADDRESS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 53
        )
        INVALID_USER_DOMAIN_NAME = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 54
        )
        CRITERION_PARAMETER_TOO_LONG = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 55
        )
        AD_SCHEDULE_TIME_INTERVALS_OVERLAP = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 56
        )
        AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 57
        )
        AD_SCHEDULE_INVALID_TIME_INTERVAL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 58
        )
        AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 59
        )
        AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 60
        )
        CANNOT_BID_MODIFY_CRITERION_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 61
        )
        CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 62
        )
        CANNOT_BID_MODIFY_NEGATIVE_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 63
        )
        BID_MODIFIER_ALREADY_EXISTS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 64
        )
        FEED_ID_NOT_ALLOWED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 65)
        ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 66
        )
        CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 67
        )
        CANNOT_EXCLUDE_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 68
        )
        CANNOT_REMOVE_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 69
        )
        INVALID_PRODUCT_BIDDING_CATEGORY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 76
        )
        MISSING_SHOPPING_SETTING = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 77
        )
        INVALID_MATCHING_FUNCTION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 78
        )
        LOCATION_FILTER_NOT_ALLOWED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 79
        )
        INVALID_FEED_FOR_LOCATION_FILTER = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 98
        )
        LOCATION_FILTER_INVALID = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 80
        )
        CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 81
        )
        HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 82
        )
        HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 83
        )
        FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 84
        )
        INVALID_WEBPAGE_CONDITION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 85
        )
        INVALID_WEBPAGE_CONDITION_URL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 86
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 87
        )
        WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 88
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 89
        )
        WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 90
        )
        WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 91
        )
        WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 92
        )
        WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 93
        )
        WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 94
        )
        WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 95
        )
        CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 99
        )
        LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 100
        )
        LISTING_SCOPE_TOO_MANY_IN_OPERATORS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 101
        )
        LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 102
        )
        DUPLICATE_LISTING_DIMENSION_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 103
        )
        DUPLICATE_LISTING_DIMENSION_VALUE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 104
        )
        CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 105
        )
        INVALID_LISTING_GROUP_HIERARCHY = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 106
        )
        LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 107
        )
        LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 108
        )
        LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 109
        )
        LISTING_GROUP_ALREADY_EXISTS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 110
        )
        LISTING_GROUP_DOES_NOT_EXIST = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 111
        )
        LISTING_GROUP_CANNOT_BE_REMOVED = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 112
        )
        INVALID_LISTING_GROUP_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 113
        )
        LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 114
        )
        LISTING_SCOPE_TOO_LONG = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 115
        )
        LISTING_SCOPE_TOO_MANY_DIMENSIONS = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 116
        )
        LISTING_GROUP_TOO_LONG = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 117
        )
        LISTING_GROUP_TREE_TOO_DEEP = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 118
        )
        INVALID_LISTING_DIMENSION = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 119
        )
        INVALID_LISTING_DIMENSION_TYPE = typing___cast(
            CriterionErrorEnum.CriterionErrorValue, 120
        )
    UNSPECIFIED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 0)
    UNKNOWN = typing___cast(CriterionErrorEnum.CriterionErrorValue, 1)
    CONCRETE_TYPE_REQUIRED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 2)
    INVALID_EXCLUDED_CATEGORY = typing___cast(CriterionErrorEnum.CriterionErrorValue, 3)
    INVALID_KEYWORD_TEXT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 4)
    KEYWORD_TEXT_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionErrorValue, 5)
    KEYWORD_HAS_TOO_MANY_WORDS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 6
    )
    KEYWORD_HAS_INVALID_CHARS = typing___cast(CriterionErrorEnum.CriterionErrorValue, 7)
    INVALID_PLACEMENT_URL = typing___cast(CriterionErrorEnum.CriterionErrorValue, 8)
    INVALID_USER_LIST = typing___cast(CriterionErrorEnum.CriterionErrorValue, 9)
    INVALID_USER_INTEREST = typing___cast(CriterionErrorEnum.CriterionErrorValue, 10)
    INVALID_FORMAT_FOR_PLACEMENT_URL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 11
    )
    PLACEMENT_URL_IS_TOO_LONG = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 12
    )
    PLACEMENT_URL_HAS_ILLEGAL_CHAR = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 13
    )
    PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 14
    )
    PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 15
    )
    INVALID_TOPIC_PATH = typing___cast(CriterionErrorEnum.CriterionErrorValue, 16)
    INVALID_YOUTUBE_CHANNEL_ID = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 17
    )
    INVALID_YOUTUBE_VIDEO_ID = typing___cast(CriterionErrorEnum.CriterionErrorValue, 18)
    YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 19
    )
    YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 20
    )
    YOUTUBE_URL_UNSUPPORTED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 21)
    CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 22
    )
    CANNOT_ADD_CRITERIA_TYPE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 23)
    CANNOT_EXCLUDE_SIMILAR_USER_LIST = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 26
    )
    CANNOT_ADD_CLOSED_USER_LIST = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 27
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 28
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 29
    )
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 30
    )
    CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 31
    )
    CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 32
    )
    CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 33
    )
    INVALID_CUSTOM_AFFINITY = typing___cast(CriterionErrorEnum.CriterionErrorValue, 96)
    INVALID_CUSTOM_INTENT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 97)
    INVALID_IP_ADDRESS = typing___cast(CriterionErrorEnum.CriterionErrorValue, 34)
    INVALID_IP_FORMAT = typing___cast(CriterionErrorEnum.CriterionErrorValue, 35)
    INVALID_MOBILE_APP = typing___cast(CriterionErrorEnum.CriterionErrorValue, 36)
    INVALID_MOBILE_APP_CATEGORY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 37
    )
    INVALID_CRITERION_ID = typing___cast(CriterionErrorEnum.CriterionErrorValue, 38)
    CANNOT_TARGET_CRITERION = typing___cast(CriterionErrorEnum.CriterionErrorValue, 39)
    CANNOT_TARGET_OBSOLETE_CRITERION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 40
    )
    CRITERION_ID_AND_TYPE_MISMATCH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 41
    )
    INVALID_PROXIMITY_RADIUS = typing___cast(CriterionErrorEnum.CriterionErrorValue, 42)
    INVALID_PROXIMITY_RADIUS_UNITS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 43
    )
    INVALID_STREETADDRESS_LENGTH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 44
    )
    INVALID_CITYNAME_LENGTH = typing___cast(CriterionErrorEnum.CriterionErrorValue, 45)
    INVALID_REGIONCODE_LENGTH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 46
    )
    INVALID_REGIONNAME_LENGTH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 47
    )
    INVALID_POSTALCODE_LENGTH = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 48
    )
    INVALID_COUNTRY_CODE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 49)
    INVALID_LATITUDE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 50)
    INVALID_LONGITUDE = typing___cast(CriterionErrorEnum.CriterionErrorValue, 51)
    PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 52
    )
    INVALID_PROXIMITY_ADDRESS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 53
    )
    INVALID_USER_DOMAIN_NAME = typing___cast(CriterionErrorEnum.CriterionErrorValue, 54)
    CRITERION_PARAMETER_TOO_LONG = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 55
    )
    AD_SCHEDULE_TIME_INTERVALS_OVERLAP = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 56
    )
    AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 57
    )
    AD_SCHEDULE_INVALID_TIME_INTERVAL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 58
    )
    AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 59
    )
    AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 60
    )
    CANNOT_BID_MODIFY_CRITERION_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 61
    )
    CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 62
    )
    CANNOT_BID_MODIFY_NEGATIVE_CRITERION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 63
    )
    BID_MODIFIER_ALREADY_EXISTS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 64
    )
    FEED_ID_NOT_ALLOWED = typing___cast(CriterionErrorEnum.CriterionErrorValue, 65)
    ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 66
    )
    CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 67
    )
    CANNOT_EXCLUDE_CRITERION = typing___cast(CriterionErrorEnum.CriterionErrorValue, 68)
    CANNOT_REMOVE_CRITERION = typing___cast(CriterionErrorEnum.CriterionErrorValue, 69)
    INVALID_PRODUCT_BIDDING_CATEGORY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 76
    )
    MISSING_SHOPPING_SETTING = typing___cast(CriterionErrorEnum.CriterionErrorValue, 77)
    INVALID_MATCHING_FUNCTION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 78
    )
    LOCATION_FILTER_NOT_ALLOWED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 79
    )
    INVALID_FEED_FOR_LOCATION_FILTER = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 98
    )
    LOCATION_FILTER_INVALID = typing___cast(CriterionErrorEnum.CriterionErrorValue, 80)
    CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 81
    )
    HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 82
    )
    HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 83
    )
    FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 84
    )
    INVALID_WEBPAGE_CONDITION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 85
    )
    INVALID_WEBPAGE_CONDITION_URL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 86
    )
    WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 87
    )
    WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 88
    )
    WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 89
    )
    WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 90
    )
    WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 91
    )
    WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 92
    )
    WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 93
    )
    WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 94
    )
    WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 95
    )
    CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 99
    )
    LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 100
    )
    LISTING_SCOPE_TOO_MANY_IN_OPERATORS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 101
    )
    LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 102
    )
    DUPLICATE_LISTING_DIMENSION_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 103
    )
    DUPLICATE_LISTING_DIMENSION_VALUE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 104
    )
    CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 105
    )
    INVALID_LISTING_GROUP_HIERARCHY = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 106
    )
    LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 107
    )
    LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 108
    )
    LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 109
    )
    LISTING_GROUP_ALREADY_EXISTS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 110
    )
    LISTING_GROUP_DOES_NOT_EXIST = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 111
    )
    LISTING_GROUP_CANNOT_BE_REMOVED = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 112
    )
    INVALID_LISTING_GROUP_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 113
    )
    LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 114
    )
    LISTING_SCOPE_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionErrorValue, 115)
    LISTING_SCOPE_TOO_MANY_DIMENSIONS = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 116
    )
    LISTING_GROUP_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionErrorValue, 117)
    LISTING_GROUP_TREE_TOO_DEEP = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 118
    )
    INVALID_LISTING_DIMENSION = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 119
    )
    INVALID_LISTING_DIMENSION_TYPE = typing___cast(
        CriterionErrorEnum.CriterionErrorValue, 120
    )
    type___CriterionError = CriterionError
    def __init__(self,) -> None: ...

type___CriterionErrorEnum = CriterionErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.frequency_cap_event_type_pb2 import (
    FrequencyCapEventTypeEnum as google___ads___googleads___v5___enums___frequency_cap_event_type_pb2___FrequencyCapEventTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.frequency_cap_level_pb2 import (
    FrequencyCapLevelEnum as google___ads___googleads___v5___enums___frequency_cap_level_pb2___FrequencyCapLevelEnum,
)
from google.ads.google_ads.v5.proto.enums.frequency_cap_time_unit_pb2 import (
    FrequencyCapTimeUnitEnum as google___ads___googleads___v5___enums___frequency_cap_time_unit_pb2___FrequencyCapTimeUnitEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FrequencyCapEntry(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    cap: builtin___int = ...
    @property
    def key(self) -> type___FrequencyCapKey: ...
    def __init__(
        self,
        *,
        key: typing___Optional[type___FrequencyCapKey] = None,
        cap: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_cap", b"_cap", "cap", b"cap", "key", b"key"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_cap", b"_cap", "cap", b"cap", "key", b"key"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_cap", b"_cap"]
    ) -> typing_extensions___Literal["cap"]: ...

type___FrequencyCapEntry = FrequencyCapEntry

class FrequencyCapKey(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    level: google___ads___googleads___v5___enums___frequency_cap_level_pb2___FrequencyCapLevelEnum.FrequencyCapLevelValue = ...
    event_type: google___ads___googleads___v5___enums___frequency_cap_event_type_pb2___FrequencyCapEventTypeEnum.FrequencyCapEventTypeValue = ...
    time_unit: google___ads___googleads___v5___enums___frequency_cap_time_unit_pb2___FrequencyCapTimeUnitEnum.FrequencyCapTimeUnitValue = ...
    time_length: builtin___int = ...
    def __init__(
        self,
        *,
        level: typing___Optional[
            google___ads___googleads___v5___enums___frequency_cap_level_pb2___FrequencyCapLevelEnum.FrequencyCapLevelValue
        ] = None,
        event_type: typing___Optional[
            google___ads___googleads___v5___enums___frequency_cap_event_type_pb2___FrequencyCapEventTypeEnum.FrequencyCapEventTypeValue
        ] = None,
        time_unit: typing___Optional[
            google___ads___googleads___v5___enums___frequency_cap_time_unit_pb2___FrequencyCapTimeUnitEnum.FrequencyCapTimeUnitValue
        ] = None,
        time_length: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_time_length", b"_time_length", "time_length", b"time_length"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_time_length",
            b"_time_length",
            "event_type",
            b"event_type",
            "level",
            b"level",
            "time_length",
            b"time_length",
            "time_unit",
            b"time_unit",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_time_length", b"_time_length"]
    ) -> typing_extensions___Literal["time_length"]: ...

type___FrequencyCapKey = FrequencyCapKey



from typing import Any

class KeywordPlanCampaignKeywordServiceStub:
    GetKeywordPlanCampaignKeyword: Any = ...
    MutateKeywordPlanCampaignKeywords: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanCampaignKeywordServiceServicer:
    def GetKeywordPlanCampaignKeyword(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlanCampaignKeywords(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanCampaignKeywordServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.keyword_plan_competition_level_pb2 import (
    KeywordPlanCompetitionLevelEnum as google___ads___googleads___v6___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum,
)
from google.ads.google_ads.v6.proto.enums.month_of_year_pb2 import (
    MonthOfYearEnum as google___ads___googleads___v6___enums___month_of_year_pb2___MonthOfYearEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanHistoricalMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    avg_monthly_searches: builtin___int = ...
    competition: google___ads___googleads___v6___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue = ...
    competition_index: builtin___int = ...
    low_top_of_page_bid_micros: builtin___int = ...
    high_top_of_page_bid_micros: builtin___int = ...
    @property
    def monthly_search_volumes(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MonthlySearchVolume
    ]: ...
    def __init__(
        self,
        *,
        avg_monthly_searches: typing___Optional[builtin___int] = None,
        monthly_search_volumes: typing___Optional[
            typing___Iterable[type___MonthlySearchVolume]
        ] = None,
        competition: typing___Optional[
            google___ads___googleads___v6___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue
        ] = None,
        competition_index: typing___Optional[builtin___int] = None,
        low_top_of_page_bid_micros: typing___Optional[builtin___int] = None,
        high_top_of_page_bid_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_avg_monthly_searches",
            b"_avg_monthly_searches",
            "_competition_index",
            b"_competition_index",
            "_high_top_of_page_bid_micros",
            b"_high_top_of_page_bid_micros",
            "_low_top_of_page_bid_micros",
            b"_low_top_of_page_bid_micros",
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_avg_monthly_searches",
            b"_avg_monthly_searches",
            "_competition_index",
            b"_competition_index",
            "_high_top_of_page_bid_micros",
            b"_high_top_of_page_bid_micros",
            "_low_top_of_page_bid_micros",
            b"_low_top_of_page_bid_micros",
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition",
            b"competition",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
            "monthly_search_volumes",
            b"monthly_search_volumes",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_avg_monthly_searches", b"_avg_monthly_searches"
        ],
    ) -> typing_extensions___Literal["avg_monthly_searches"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_competition_index", b"_competition_index"
        ],
    ) -> typing_extensions___Literal["competition_index"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_high_top_of_page_bid_micros", b"_high_top_of_page_bid_micros"
        ],
    ) -> typing_extensions___Literal["high_top_of_page_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_low_top_of_page_bid_micros", b"_low_top_of_page_bid_micros"
        ],
    ) -> typing_extensions___Literal["low_top_of_page_bid_micros"]: ...

type___KeywordPlanHistoricalMetrics = KeywordPlanHistoricalMetrics

class MonthlySearchVolume(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    year: builtin___int = ...
    month: google___ads___googleads___v6___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue = ...
    monthly_searches: builtin___int = ...
    def __init__(
        self,
        *,
        year: typing___Optional[builtin___int] = None,
        month: typing___Optional[
            google___ads___googleads___v6___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue
        ] = None,
        monthly_searches: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_monthly_searches",
            b"_monthly_searches",
            "_year",
            b"_year",
            "monthly_searches",
            b"monthly_searches",
            "year",
            b"year",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_monthly_searches",
            b"_monthly_searches",
            "_year",
            b"_year",
            "month",
            b"month",
            "monthly_searches",
            b"monthly_searches",
            "year",
            b"year",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_monthly_searches", b"_monthly_searches"
        ],
    ) -> typing_extensions___Literal["monthly_searches"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_year", b"_year"]
    ) -> typing_extensions___Literal["year"]: ...

type___MonthlySearchVolume = MonthlySearchVolume



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ReachPlanNetworkEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ReachPlanNetworkValue = typing___NewType("ReachPlanNetworkValue", builtin___int)
    type___ReachPlanNetworkValue = ReachPlanNetworkValue
    ReachPlanNetwork: _ReachPlanNetwork
    class _ReachPlanNetwork(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ReachPlanNetworkEnum.ReachPlanNetworkValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 0)
        UNKNOWN = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 1)
        YOUTUBE = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 2)
        GOOGLE_VIDEO_PARTNERS = typing___cast(
            ReachPlanNetworkEnum.ReachPlanNetworkValue, 3
        )
        YOUTUBE_AND_GOOGLE_VIDEO_PARTNERS = typing___cast(
            ReachPlanNetworkEnum.ReachPlanNetworkValue, 4
        )
    UNSPECIFIED = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 0)
    UNKNOWN = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 1)
    YOUTUBE = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 2)
    GOOGLE_VIDEO_PARTNERS = typing___cast(ReachPlanNetworkEnum.ReachPlanNetworkValue, 3)
    YOUTUBE_AND_GOOGLE_VIDEO_PARTNERS = typing___cast(
        ReachPlanNetworkEnum.ReachPlanNetworkValue, 4
    )
    type___ReachPlanNetwork = ReachPlanNetwork
    def __init__(self,) -> None: ...

type___ReachPlanNetworkEnum = ReachPlanNetworkEnum



from typing import Any

class SearchTermViewServiceStub:
    GetSearchTermView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class SearchTermViewServiceServicer:
    def GetSearchTermView(self, request: Any, context: Any) -> None: ...

def add_SearchTermViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
